<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 * 
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 620; /* pixels */
}

if ( ! function_exists( 'smartzine_content_width' ) ) :
/**
 * Set new content width if user uses 1 column layout.
 *
 * @since  1.0.0
 */
function smartzine_content_width() {
	global $content_width;

	if ( in_array( get_theme_mod( 'theme_layout' ), array( '1c' ) ) ) {
		$content_width = 940;
	}
}
endif;
add_action( 'template_redirect', 'smartzine_content_width' );

if ( ! function_exists( 'smartzine_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since  1.0.0
 */
function smartzine_theme_setup() {

	// Make the theme available for translation.
	load_theme_textdomain( 'smartzine', trailingslashit( get_template_directory() ) . 'languages' );

	// Add custom stylesheet file to the TinyMCE visual editor.
	add_editor_style( array( 'assets/css/editor-style.css', smartzine_font_url() ) );

	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails.
	add_theme_support( 'post-thumbnails' );

	// used in Blog Grid, Blog List and Home Widgets (300x200)
	set_post_thumbnail_size( 300, 200, true );

	// Declare image sizes.
	add_image_size( 'smartzine-widget-thumb', 64, 64, true );
	add_image_size( 'smartzine-megamenu-posts', 230, 140, true );
	add_image_size( 'smartzine-related', 600, 340, true ); // (300x170)
	add_image_size( 'smartzine-threecolposts-big', 460, 260, true );
	add_image_size( 'smartzine-threecolposts-small', 220, 140, true );

	// Register custom navigation menu.
	register_nav_menus(
		array(
			'primary'   => __( 'Primary Location', 'smartzine' ),
			'secondary' => __( 'Secondary Location' , 'smartzine' ),
		)
	);

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-list', 'search-form', 'comment-form', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 * See: http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'gallery', 'image', 'link', 'quote', 'video'
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'smartzine_custom_background_args', array(
		'default-color' => 'eee',
		'default-image' => '',
	) ) );

	// Enable theme-layouts extensions.
	add_theme_support( 'theme-layouts', 
		array(
			'1c'   => __( '1 Column Wide (Full Width)', 'smartzine' ),
			'2c-l' => __( '2 Columns: Content / Sidebar', 'smartzine' ),
			'2c-r' => __( '2 Columns: Sidebar / Content', 'smartzine' )
		),
		array( 'customize' => true, 'default' => '2c-l' ) 
	);

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );

}
endif; // smartzine_theme_setup
add_action( 'after_setup_theme', 'smartzine_theme_setup' );

if ( ! function_exists( 'smartzine_reset_default_image_sizes' ) ) :
/**
 * Re-set default image sizes
 *
 * @since  1.0.0
 */
function smartzine_reset_default_image_sizes() {
	// 'large' size: slider
	update_option( 'large_size_w', 940 );
	update_option( 'large_size_h', 540 );
	update_option( 'large_crop', 1 );

	// 'medium' size: featured image
	update_option( 'medium_size_w', 620 );
	update_option( 'medium_size_h', 420 );
	update_option( 'medium_crop', 1 );

	// 'thumbnail' size: slider thumbnails
	update_option( 'thumbnail_size_w', 84 );
	update_option( 'thumbnail_size_h', 84 );
	update_option( 'thumbnail_crop', 1 );
}
endif;
add_action( 'after_switch_theme', 'smartzine_reset_default_image_sizes' );

if ( ! function_exists( 'smartzine_revert_default_image_sizes' ) ) :
/**
 * Revert default image sizes while theme switched
 *
 * @since  1.0.0
 */
function smartzine_revert_default_image_sizes() {
	// 'large' size
	update_option( 'large_size_w', 1024 );
	update_option( 'large_size_h', 1024 );
	update_option( 'large_crop', 1 );

	// 'medium' size
	update_option( 'medium_size_w', 300 );
	update_option( 'medium_size_h', 300 );
	update_option( 'medium_crop', 1 );

	// 'thumbnail' size
	update_option( 'thumbnail_size_w', 150 );
	update_option( 'thumbnail_size_h', 150 );
	update_option( 'thumbnail_crop', 1 );	
}
endif;
add_action( 'switch_theme', 'smartzine_revert_default_image_sizes' );

/**
 * Registers custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function smartzine_widgets_init() {

	// Register ad widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-ads.php';
	register_widget( 'SmartZine_Ads_Widget' );

	// Register ad 125 widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-ads125.php';
	register_widget( 'SmartZine_Ads125_Widget' );

	// Register facebook widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-facebook.php';
	register_widget( 'SmartZine_Facebook_Widget' );

	// Register feedburner widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-feedburner.php';
	register_widget( 'SmartZine_Feedburner_Widget' );

	// Register recent posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-recent.php';
	register_widget( 'SmartZine_Recent_Widget' );

	// Register popular posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-popular.php';
	register_widget( 'SmartZine_Popular_Widget' );

	// Register random posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-random.php';
	register_widget( 'SmartZine_Random_Widget' );

	// Register most views posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-views.php';
	register_widget( 'SmartZine_Views_Widget' );

	// Register tabs widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-tabs.php';
	register_widget( 'SmartZine_Tabs_Widget' );

	// Register twitter widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-twitter.php';
	register_widget( 'SmartZine_Twitter_Widget' );

	// Register video widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-video.php';
	register_widget( 'SmartZine_Video_Widget' );
	
	// Register home slider widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-home-slider.php';
	register_widget( 'SmartZine_Home_Slider_Widget' );

	// Register home grid/list widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-home-gridlist.php';
	register_widget( 'SmartZine_Home_Grid_List_Widget' );

	// Register home special widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-home-special.php';
	register_widget( 'SmartZine_Home_Special_Widget' );

}
add_action( 'widgets_init', 'smartzine_widgets_init' );

/**
 * Registers widget areas and custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function smartzine_sidebars_init() {

	register_sidebar(
		array(
			'name'          => __( 'Primary', 'smartzine' ),
			'id'            => 'primary',
			'description'   => __( 'Main sidebar that appears on the right.', 'smartzine' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 1', 'smartzine' ),
			'id'            => 'footer-1',
			'description'   => __( 'The footer sidebar 1st column.', 'smartzine' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 2', 'smartzine' ),
			'id'            => 'footer-2',
			'description'   => __( 'The footer sidebar 2nd column.', 'smartzine' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 3', 'smartzine' ),
			'id'            => 'footer-3',
			'description'   => __( 'The footer sidebar 3rd column.', 'smartzine' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 4', 'smartzine' ),
			'id'            => 'footer-4',
			'description'   => __( 'The footer sidebar 4th column.', 'smartzine' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Home', 'smartzine' ),
			'id'            => 'home',
			'description'   => __( 'Widget Area for Home page template', 'smartzine' ),
			'before_widget' => '<div id="%1$s" class="home-widget clearfix %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="heading">',
			'after_title'   => '</h3>',
		)
	);
	
}
add_action( 'widgets_init', 'smartzine_sidebars_init' );

/**
 * Register Lato Google font.
 *
 * @since  1.0.0
 * @return string
 */
function smartzine_font_url() {
	
	$font_url = '';
	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Lato, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Lato font: on or off', 'smartzine' ) ) {
		$font_url = add_query_arg( 'family', urlencode( 'Lato:300,400,700,900,300italic,400italic,700italic' ), "//fonts.googleapis.com/css" );
	}

	return $font_url;
}

/**
 * Function to check if a plugin exist
 *
 * @since  1.0.0
 */
function smartzine_plugin_exist( $name ) {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	is_plugin_active( $name );
}

/**
 * Custom template tags for this theme.
 */
require trailingslashit( get_template_directory() ) . 'inc/template-tags.php';

/**
 * Enqueue scripts and styles.
 */
require trailingslashit( get_template_directory() ) . 'inc/scripts.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit( get_template_directory() ) . 'inc/extras.php';

/**
 * Require and recommended plugins list.
 */
require trailingslashit( get_template_directory() ) . 'inc/plugins.php';

/**
 * Load Jetpack compatibility file.
 */
require trailingslashit( get_template_directory() ) . 'inc/jetpack.php';

/**
 * Customizer.
 */
require trailingslashit( get_template_directory() ) . 'admin/customizer-library.php';
require trailingslashit( get_template_directory() ) . 'admin/functions.php';

/**
 * Customizer functions.
 */
require trailingslashit( get_template_directory() ) . 'inc/customizer.php';
require trailingslashit( get_template_directory() ) . 'inc/mods.php';

/**
 * Mega menus walker.
 */
require trailingslashit( get_template_directory() ) . 'inc/megamenus/init.php';
require trailingslashit( get_template_directory() ) . 'inc/megamenus/class-primary-nav-walker.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require trailingslashit( get_template_directory() ) . 'inc/hybrid/attr.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/breadcrumb-trail.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/theme-layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/entry-views.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/hybrid-media-grabber.php';

/**
 * Demo importer
 */
require trailingslashit( get_template_directory() ) . 'inc/demo/demo-importer.php';

// MailOptin integration
require get_template_directory() . '/inc/mailoptin.php';
